@@ -340,9 +340,6 @@ class DensOp(ctypes.Structure):
         elm[1][1] = +0.5000+0.0000*i : 0.2500 |++++
 
         """
-        # de_part = self.partial(qid=qid)
-        # densop_print(de_part, nonzero)
-
         de_part = self.partial(qid=qid)
         mat = de_part.get_elm()
         for i in range(de_part.row):
@@ -1810,7 +1807,7 @@ class DensOp(ctypes.Structure):
         densop_mcx(self, qid)
         return self
 
-    def operate(self, pp=None, ctrl=None):
+    def operate(self, pp=None, ctrl=None, qctrl=None):
         """
         operate unitary operator to density operator.
 
@@ -1820,6 +1817,9 @@ class DensOp(ctypes.Structure):
             pauli product to operate
         ctrl : int
             contoroll qubit id for controlled pauli product
+            (this option will be removed near future)
+        qctrl : int
+            contoroll qubit id for controlled pauli product
 
         Returns
         -------
@@ -1831,6 +1831,9 @@ class DensOp(ctypes.Structure):
         qid = pp.qid
         factor = pp.factor
 
+        if ctrl is None:
+            ctrl = qctrl
+
         if ctrl is None:
             for q, pauli in zip(qid, pauli_list):
                 if pauli == 'X':
