@@ -1585,7 +1585,7 @@ class MPState(FiniteMPS):
 
         return self
 
-    def operate(self, pp=None, ctrl=None):
+    def operate(self, pp=None, ctrl=None, qctrl=None):
         """
         operate unitary operator to quantum state.
 
@@ -1595,6 +1595,9 @@ class MPState(FiniteMPS):
             pauli product to operate
         ctrl : int
             contoroll qubit id for controlled pauli product
+            (this option will be removed near future)
+        qctrl : int
+            contoroll qubit id for controlled pauli product
 
         Returns
         -------
@@ -1610,6 +1613,9 @@ class MPState(FiniteMPS):
         qid = pp.qid
         factor = pp.factor
 
+        if ctrl is None:
+            ctrl = qctrl
+
         if ctrl is None:
             for q, pauli in zip(qid, pauli_list):
                 if pauli == 'X':
@@ -1666,6 +1672,9 @@ class MPState(FiniteMPS):
         if ob.recalc_weight() is False:
             raise ValueError("Observable is not hermitian.")
 
+        if self.qubit_num < ob.qubit_num:
+            raise ValueError("total qubit number of the observable must be less than mpstate's.")
+
         expect_value = 0.0
         weighted_pp_list = ob.weighted_pp_list
         for wpp in weighted_pp_list:
