@@ -636,6 +636,9 @@ class QState(ctypes.Structure):
         if ob.recalc_weight() is False:
             raise ValueError("Observable is not hermitian.")
 
+        if self.qubit_num < ob.qubit_num:
+            raise ValueError("total qubit number of the observable must be less than qstate's.")
+
         expect = qstate_expect_value(self, observable=ob.base)
         return expect
 
@@ -1561,7 +1564,7 @@ class QState(ctypes.Structure):
         """ bell measurement """
         return qstate_measure_bell_stats(self, qid=qid, shots=shots)
 
-    def operate(self, pp=None, ctrl=None):
+    def operate(self, pp=None, ctrl=None, qctrl=None):
         """
         operate unitary operator to quantum state.
 
@@ -1571,6 +1574,9 @@ class QState(ctypes.Structure):
             pauli product to operate
         ctrl : int
             contoroll qubit id for controlled pauli product
+            (this option will be removed near future)
+        qctrl : int
+            contoroll qubit id for controlled pauli product
 
         Returns
         -------
@@ -1582,6 +1588,9 @@ class QState(ctypes.Structure):
         qid = pp.qid
         factor = pp.factor
 
+        if ctrl is None:
+            ctrl = qctrl
+
         if ctrl is None:
             for q, pauli in zip(qid, pauli_list):
                 if pauli == 'X':
