@@ -707,7 +707,7 @@ class Stabilizer(ctypes.Structure):
             else:
                 raise ValueError("can't free stabilizer.")
 
-    def operate(self, pp=None, ctrl=None):
+    def operate(self, pp=None, ctrl=None, qctrl=None):
         """
         operate unitary operator to stabilizer.
 
@@ -717,6 +717,9 @@ class Stabilizer(ctypes.Structure):
             pauli product to operate
         ctrl : int
             contoroll qubit id for controlled pauli product
+            (this option will be removed near future)
+        qctrl : int
+            contoroll qubit id for controlled pauli product
 
         Returns
         -------
@@ -728,6 +731,9 @@ class Stabilizer(ctypes.Structure):
         qid = pp.qid
         factor = pp.factor
 
+        if ctrl is None:
+            ctrl = qctrl
+
         if ctrl is None:
             for q, pauli in zip(qid, pauli_list):
                 if pauli == 'X':
