@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 from .QState import QState
+from .ObservableBase import ObservableBase
 from .Observable import Observable
 from .DensOp import DensOp
 from .Stabilizer import Stabilizer
+from .MPState import MPState
 from .Backend import Backend
 from .QCirc import QCirc
 from .CMem import CMem
@@ -13,5 +15,5 @@ from . import error
 from . import util
 from . import gpu
 
-__all__ = ["QState", "Observable", "DensOp", "Stabilizer", "Backend", "QCirc", "CMem",
-           "PauliProduct", "Result", "config", "error", "util", "gpu"]
+__all__ = ["QState", "ObservableBase", "Observable", "DensOp", "Stabilizer", "MPState",
+           "Backend", "QCirc", "CMem", "PauliProduct", "Result", "config", "error", "util", "gpu"]
